==> haskell-quickcheck-unicode-1.0.1.0-317-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-quickcheck-unicode.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 quickcheck-unicode
version:              1.0.1.0
visibility:           public
id:                   quickcheck-unicode-1.0.1.0-7Uk3aH6US49IJQfMNW2qrU
key:                  quickcheck-unicode-1.0.1.0-7Uk3aH6US49IJQfMNW2qrU
license:              BSD-2-Clause
copyright:            2014-2017 Bryan O'\''Sullivan
maintainer:           Bryan O'\''Sullivan <bos@serpentine.com>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
homepage:             https://github.com/bos/quickcheck-unicode
synopsis:
    Generator and shrink functions for testing
    Unicode-related software.

description:
    Generator and shrink functions for testing
    Unicode-related software.

category:             Testing, Text
abi:                  2d8f4c6ff727cc6f3334487c9062e929
exposed:              True
exposed-modules:      Test.QuickCheck.Unicode
import-dirs:          /usr/lib/ghc-9.4.8/site-local/quickcheck-unicode-1.0.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/quickcheck-unicode-1.0.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/quickcheck-unicode-1.0.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-quickcheck-unicode
hs-libraries:         HSquickcheck-unicode-1.0.1.0-7Uk3aH6US49IJQfMNW2qrU
depends:
    QuickCheck-2.15.0.1-9BbRJGxXLRp2lnC2CpyIBM base-4.17.2.1

haddock-interfaces:
    /usr/share/doc/haskell-quickcheck-unicode/html/quickcheck-unicode.haddock

haddock-html:         /usr/share/doc/haskell-quickcheck-unicode/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-quickcheck-unicode-1.0.1.0-318-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-quickcheck-unicode.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 quickcheck-unicode
version:              1.0.1.0
visibility:           public
id:                   quickcheck-unicode-1.0.1.0-3lLwkavGspg6PcLYytlKgn
key:                  quickcheck-unicode-1.0.1.0-3lLwkavGspg6PcLYytlKgn
license:              BSD-2-Clause
copyright:            2014-2017 Bryan O'\''Sullivan
maintainer:           Bryan O'\''Sullivan <bos@serpentine.com>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
homepage:             https://github.com/bos/quickcheck-unicode
synopsis:
    Generator and shrink functions for testing
    Unicode-related software.

description:
    Generator and shrink functions for testing
    Unicode-related software.

category:             Testing, Text
abi:                  8873663bd8aaec1f0a3aa8a6d3820553
exposed:              True
exposed-modules:      Test.QuickCheck.Unicode
import-dirs:          /usr/lib/ghc-9.4.8/site-local/quickcheck-unicode-1.0.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/quickcheck-unicode-1.0.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/quickcheck-unicode-1.0.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-quickcheck-unicode
hs-libraries:         HSquickcheck-unicode-1.0.1.0-3lLwkavGspg6PcLYytlKgn
depends:
    QuickCheck-2.15.0.1-59GGzHy0g7bISHsBJt3oMz base-4.17.2.1

haddock-interfaces:
    /usr/share/doc/haskell-quickcheck-unicode/html/quickcheck-unicode.haddock

haddock-html:         /usr/share/doc/haskell-quickcheck-unicode/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
